##########
User's API
##########

.. autoclass:: MoranProcess::MoranProcess
    :noindex:
    :special-members:
    :exclude-members: __weakref__
    :member-order: bysource
    :members:

.. autoclass:: MoranProcess2D::MoranProcess2D
    :noindex:
    :special-members:
    :exclude-members: __weakref__
    :member-order: bysource
    :members:

.. autoclass:: MoranProcess3D::MoranProcess3D
    :noindex:
    :special-members:
    :exclude-members: __weakref__
    :member-order: bysource
    :members:
